class Tag < ApplicationRecord
  has_many :post_tags, dependent: :destroy
  has_many :posts, through: :post_tags
  has_many :tag_aliases, dependent: :destroy
  has_many :wiki_pages, dependent: :nullify

  enum :category, { deerjikist:  'deerjikist',
                    meme:        'meme',
                    character:   'character',
                    general:     'general',
                    material:    'material',
                    nico:        'nico',
                    meta:        'meta' }

  validates :name, presence: true, length: { maximum: 255 }
  validates :category, presence: true, inclusion: { in: Tag.categories.keys }

  validate :nico_tag_name_must_start_with_nico

  scope :nico_tags, -> { where category: :nico }

  private

  def nico_tag_name_must_start_with_nico
    if category == 'nico' && name&.[](0, 5) != 'nico:'
      errors.add :name, 'ニコニコ・タグの命名規則に反してゐます．'
    end
  end
end
