import axios from 'axios'
import toCamel from 'camelcase-keys'
import React, { useEffect, useState } from 'react'
import { Link, useNavigate, useLocation } from 'react-router-dom'

import { Button } from '@/components/ui/button'
import { Dialog,
         DialogContent,
         DialogDescription,
         DialogTitle,
         DialogTrigger } from '@/components/ui/dialog'
import { Input } from '@/components/ui/input'
import { Switch } from '@/components/ui/switch'
import { toast } from '@/components/ui/use-toast'
import { API_BASE_URL } from '@/config'

import type { Tag, User } from '@/types'

type Props = { visible:         boolean
               onVisibleChange: (visible: boolean) => void
               user:            User
               setUser:         (user: User) => void }


const SettingsDialogue: React.FC = ({ visible,
                                      onVisibleChange,
                                      user,
                                      setUser }: Props) => {
  const [inputCode, setInputCode] = useState ('')

  const handleShowCode = () => {
    if (user?.inheritanceCode)
      toast ({ title: 'あなたの引継ぎコード', description: user.inheritanceCode })
    else
      toast ({ title: '引継ぎコードが見つかりません．' })
  }

  const handleTransfer = async () => {
    try
    {
      void (axios.post (`${ API_BASE_URL }/users/verify`, { code: inputCode })
            .then (res => {
              if (res.data.valid)
                {
                  localStorage.setItem ('user_code', inputCode)
                  setUser (toCamel (res.data.user, { deep: true }))
                  toast ({ title: '引継ぎ成功!' })
                }
              else
                toast ({ title: '認証失敗', description: 'そのコードは使へません．' })
            }))
    }
    catch (e)
    {
      toast ({ title: '通信エラー', description: 'またあとで試してね．' })
    }
  }

  return (
      <Dialog open={visible} onOpenChange={onVisibleChange}>
        <DialogContent className="space-y-6">
          <DialogTitle>ユーザ設定</DialogTitle>
          <DialogDescription>
            ユーザの設定や引継ぎコードの確認、変更ができます。
          </DialogDescription>
          <div>
            <p className="mb-1 font-semibold">引継ぎコード</p>
            <Button variant="secondary" onClick={handleShowCode}>
              引継ぎコードを表示
            </Button>
          </div>
          <div>
            <p className="mb-1 font-semibold">ほかのブラウザから引継ぐ</p>
            <div className="flex gap-2">
              <Input placeholder="引継ぎコードを入力"
                     value={inputCode}
                     onChange={e => setInputCode (e.target.value)} />
              <Button onClick={handleTransfer}>引継ぐ</Button>
            </div>
          </div>
        </DialogContent>
      </Dialog>)
}


export default SettingsDialogue
