import React, { useEffect, useState } from 'react'
import axios from 'axios'
import { Link, useNavigate, useLocation } from 'react-router-dom'
import { API_BASE_URL } from '@/config'
import { cn } from '@/lib/utils'

import type { Tag } from '@/types'

type Props = { suggestions: Tag[]
               activeIndex: number
               onSelect:    (tag: Tag) => void }


const TagSearchBox: React.FC = (props: Props) => {
  const { suggestions, activeIndex, onSelect } = props

  if (!(suggestions.length))
    return null

  const navigate = useNavigate ()
  const location = useLocation ()

  return (
      <ul className="absolute left-0 right-0 z-50 w-full bg-gray-800 border border-gray-600 rounded shadow">
        {suggestions.map ((tag, i) => (
            <li key={tag.id}
                className={cn ('px-3 py-2 cursor-pointer', 
                               (i === activeIndex
                                ? 'bg-blue-600 text-white'
                                : 'hover:bg-gray-700'))}
                onMouseDown={() => onSelect (tag)}
            >
              {tag.name}
              {<span className="ml-2 text-sm text-gray-400">{tag.count}</span>}
            </li>))}
      </ul>)
}


export default TagSearchBox
